#
# spec file for package python3-simplejson
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-simplejson
Version:        3.8.0
Release:        5.18
Url:            http://github.com/simplejson/simplejson
Summary:        Simple, fast, extensible JSON encoder/decoder for Python
License:        MIT or AFL-2.1
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/s/simplejson/simplejson-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3 >= 3.3
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires:       python3-coverage
Requires:       python3-nose

%description
simplejson is a simple, fast, complete, correct and extensible
JSON encoder and decoder for Python 2.5+. It is pure Python code
with no dependencies, but includes an optional C extension for a
serious speed boost.

%prep
%setup -q -n simplejson-%{version}

%build
CFLAGS="%{optflags} -fno-strict-aliasing" python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%check
python3 setup.py test

%files
%defattr(-,root,root)
%doc CHANGES.txt LICENSE.txt README.rst
%{python3_sitearch}/simplejson/
%{python3_sitearch}/simplejson-%{version}-py%{py3_ver}.egg-info

%changelog
* Sat Jul 18 2015 arun@gmx.de
- update to version 3.8.0:
  * New iterable_as_array encoder option to perform lazy serialization
    of any iterable objects, without having to convert to tuple or
    list.
* Fri Jun  5 2015 arun@gmx.de
- update to version 3.7.3:
  * Fix typo introduced in 3.7.0 (behavior should be indistinguishable)
    https://github.com/simplejson/simplejson/commit/e18cc09b688ea1f3305c27616fd3cadd2adc6d31#commitcomment-11443842
* Sat May 30 2015 arun@gmx.de
- specfile:
  * update copyright year
- update to version 3.7.2:
  * Do not cache Decimal class in encoder, only reference the decimal
    module.  This may make reload work in more common scenarios.
- changes from Version 3.7.1:
  * Fix compilation with MSVC
    https://github.com/simplejson/simplejson/pull/119
- changes from Version 3.7.0:
  * simplejson no longer trusts custom str/repr methods for int, long,
    float subclasses. These instances are now formatted as if they
    were exact instances of those types.
    https://github.com/simplejson/simplejson/issues/118
* Sat Nov 29 2014 arun@gmx.de
- Update to version 3.6.5
  * Importing bug fix for reference leak when an error occurs during
    dict encoding https://github.com/simplejson/simplejson/issues/109
- Changes from version.6.4
  * Important bug fix for dump when only sort_keys is set
    https://github.com/simplejson/simplejson/issues/106
- Changes from version 3.6.3
  * Documentation updates
    https://github.com/simplejson/simplejson/issues/103
- Changes from version 3.6.2
  * Documentation updates
    http://bugs.python.org/issue21514
-Changes from version 3.6.1
  * Documentation updates
    https://github.com/simplejson/simplejson/issues/102
- Changes from version 3.6.0
  * Automatically strip any UTF-8 BOM from input to more closely
    follow the latest specs https://github.com/simplejson/simplejson/pull/101
- Changes from version 3.5.3
  * Fix lower bound checking in scan_once / raw_decode API
    https://github.com/simplejson/simplejson/issues/98
- Changes from version 3.5.2
  * Fix Windows build with VS2008
    https://github.com/simplejson/simplejson/pull/97
- Changes from version 3.5.1
  * Consistently reject int_as_string_bitcount settings that are not
    positive integers
- Changes from version 3.5.0
  * Added int_as_string_bitcount encoder option
    https://github.com/simplejson/pull/96
  * Fixed potential crash when encoder created with incorrect options
* Tue May 20 2014 toddrme2178@gmail.com
- Update to 3.4.1
  * Fixed tests to run on Python 3.4
- Update to 3.4.0
  * Native setuptools support re-introduced
    https://github.com/simplejson/simplejson/pull/92
- Update to 3.3.3
  * Improve test suite's Python 3.4 compatibility
    https://github.com/simplejson/simplejson/issues/87
- Update to 3.3.2
  * Docstring fix for decoded string types
    https://github.com/simplejson/simplejson/pull/82
- update to 3.3.1:
  * JSONDecodeError exceptions can now be pickled
- Require python-setuptools instead of distribute (upstreams merged)
* Thu Aug  1 2013 speilicke@suse.com
- No need to run 2to3 anymore, fixes testsuite
* Wed May  8 2013 benny.gaechter@gmail.com
- Update to version 3.3.0
  * Unpaired surrogates once again pass through the decoder, to match older
    behavior and the RFC-4627 spec.
    https://github.com/simplejson/simplejson/issues/62
* Thu Feb 21 2013 p.drouand@gmail.com
- Disable building on python3 < 3.3 since it is not supported
- Update to version 3.1.3
  * Updated documentation to discourage subclassing whenever possible.
    default, object_hook, and object_pairs_hook provide almost all of
    the functionality of subclassing.
- Update to version 3.1.2
  * Updated documentation to reflect separators behavior when indent is
    not None
  * Test suite should be compatible with debug builds of Python 2.x and 3.x
- Update to version 3.1.1
  * setup.py now has another workaround for Windows machines without
    MSVC installed
- Update to version 3.1.0
  * Updated JSON conformance test suite
  * simplejson.tool tests and bugfix for Python 3.x
  * Improve error messages for certain kinds of truncated input
  * Moved JSONDecodeError to json.scanner (still available for import
    from json.decoder)
  * Changed scanner to use JSONDecodeError directly rather than
    StopIteration to improve error messages
- Update to version 3.0.9
  * Fix an off-by-one error in the colno property of JSONDecodeError
    (when lineno == 1)
* Thu Feb 21 2013 p.drouand@gmail.com
- Update to version 3.0.8:
  * Fix a Python 2.x compiler warning for narrow unicode builds
    https://github.com/simplejson/simplejson/issues/56
* Wed Jan 30 2013 saschpe@suse.de
- Use 2to3 to fix build, disable testsuite for now
* Thu Jan 17 2013 toddrme2178@gmail.com
- Update to 3.0.7
  * NOTE: this release only changes the license.
  * simplejson is now dual-licensed software, MIT or AFL v2.1. It is
    also made explicit that this code is also licensed to the PSF under
    a Contributor Agreement.
- Update to 3.0.7
  * Fix for major Python 2.x ensure_ascii=False encoding regression
    introduced in simplejson 3.0.0. If you use this setting, please
    upgrade immediately.
* Fri Jan 11 2013 p.drouand@gmail.com
- Initial python3 support
